/**
 * Legato is a configurable, lightweight web mapping client that can be
 * easily embedded into web pages and portals, CMS and individual web
 * applications. Legato is implemented in JavaScript and based on the
 * popular open source library OpenLayers.
 *
 * Copyright (C) 2010  disy Informationssysteme GmbH, http://www.disy.net
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.disy.legato.tools.jts;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import net.disy.commons.dwr.convert.AbstractConverter;

import org.directwebremoting.extend.InboundContext;
import org.directwebremoting.extend.InboundVariable;
import org.directwebremoting.extend.MarshallException;
import org.directwebremoting.extend.OutboundContext;
import org.directwebremoting.extend.OutboundVariable;

public class GenericGeometryConverter extends AbstractConverter {
  
  private final List<AbstractGeometryConverter<?, ?>> converters = new ArrayList<AbstractGeometryConverter<?, ?>>();
  
  public GenericGeometryConverter() {
    converters.add(new PointConverter());
    converters.add(new LineStringConverter());
    converters.add(new PolygonConverter());
    converters.add(new MultiPointConverter());
    converters.add(new MultiLineStringConverter());
    converters.add(new MultiPolygonConverter());
  }
  
  @Override
  protected Object convertInbound(
      @SuppressWarnings("rawtypes") Class paramType,
      InboundVariable data,
      Map<String, String> tokens,
      InboundContext inctx,
      String value) throws MarshallException {
    for (AbstractGeometryConverter<?, ?> converter : converters) {
      try {
        //unsure about this
        converter.setConverterManager(getConverterManager());
        return converter.convertInbound(paramType, data, tokens, inctx, value);
      }
      catch (MarshallException e) {
        continue;
      }
    }
    throw new MarshallException(paramType, "No geometry could be created from the given object.");
  }
  
  @Override
  public OutboundVariable convertOutbound(Object data, OutboundContext outctx)
      throws MarshallException {
    for (AbstractGeometryConverter<?, ?> converter : converters) {
      try {
        converter.setConverterManager(getConverterManager());
        return converter.convertOutbound(data, outctx);
      }
      catch (MarshallException e) {
        continue;
      }
    }
    //unsure about this
    throw new MarshallException(this.getClass(), "The given object could not be marshalled as a geometry object.");
  }

}
