/**
 * Legato is a configurable, lightweight web mapping client that can be
 * easily embedded into web pages and portals, CMS and individual web
 * applications. Legato is implemented in JavaScript and based on the
 * popular open source library OpenLayers.
 *
 * Copyright (C) 2010  disy Informationssysteme GmbH, http://www.disy.net
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.disy.legato.tools.util;

import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.io.Reader;
import java.io.Writer;
import java.util.Map;
import java.util.Properties;

/**
 * Similar to Spring PropertiesPersister, but operates on {@link Map}s instead
 * of {@link Properties}.
 */
public interface PropertiesMapPersister {

	/**
	 * Load properties from the given InputStream into the given map.
	 * 
	 * @param props
	 *            the Properties object to load into
	 * @param is
	 *            the InputStream to load from
	 * @throws IOException
	 *             in case of I/O errors
	 * @see java.util.Properties#load
	 */
	public void load(Map<String, String> props, InputStream is)
			throws IOException;

	/**
	 * Load properties from the given Reader into the given map.
	 * 
	 * @param props
	 *            the Properties object to load into
	 * @param reader
	 *            the Reader to load from
	 * @throws IOException
	 *             in case of I/O errors
	 */
	public void load(Map<String, String> props, Reader reader)
			throws IOException;

	/**
	 * Save properties from the given map into the given output stream.
	 * 
	 * @param props
	 *            properties map.
	 * 
	 * @param os
	 *            output stream.
	 * @param header
	 *            header.
	 * @throws IOException
	 *             In case of I/O errors.
	 */
	public void store(Map<String, String> props, OutputStream os, String header)
			throws IOException;

	/**
	 * Save properties from the given map into the given writer.
	 * 
	 * @param props
	 *            properties map.
	 * @param writer
	 *            writer for the output.
	 * @param header
	 *            header.
	 * @throws IOException
	 *             In case of I/O errors.
	 */
	public void store(Map<String, String> props, Writer writer, String header)
			throws IOException;
}
